@@ -63,7 +63,7 @@ class DAGDefinition:
         compute = PythonOperator(task_id='etl_tasks', python_callable=lambda: self.local(write=True), dag=dag)
 
         if hasattr(self, "dependencies"):
-            subscribe_to(self.spec["dag_id"], self.dependencies) >> compute
+            subscribe_to(self.dependencies) >> compute
 
         globals()[self.spec["dag_id"]] = dag
         return globals()[self.spec["dag_id"]]
