@@ -11,28 +11,18 @@ def edge_from(parent_id):
     return f"WAIT_FOR--{parent_name}"
 
 
-def subscribe_to(dag_id, parent_dag_ids, timeout=3600, allowed_states=['success'], failed_states=['failed', 'skipped'],
+def subscribe_to(parent_dag_ids, timeout=3600, allowed_states=['success'], failed_states=['failed', 'skipped'],
                  mode="reschedule"):
     tasks = []
     for parent_id in parent_dag_ids:
         tasks.append(ExternalTaskSensor(
             task_id=edge_from(parent_id),
             external_dag_id=parent_id,
-            external_task_id=edge_to(dag_id),
+            external_task_id=None,
             timeout=timeout,
+            check_existence=True,
             allowed_states=allowed_states,
             failed_states=failed_states,
             mode=mode,
         ))
     return tasks
-
-
-def notify(dag_id, child_dag_ids):
-    tasks = []
-    for child_id in child_dag_ids:
-        tasks.append(ExternalTaskMarker(
-            task_id=edge_to(child_id),
-            external_dag_id=child_id,
-            external_task_id=edge_from(dag_id),
-        ))
-    return tasks
